@@ -1,11 +1,13 @@
 from .gwcloud import GWCloud
 from .bilby_job import BilbyJob
 from .event_id import EventID
-from .file_reference import FileReference, FileReferenceList
-from .helpers import TimeRange, Cluster, JobStatus
+
+from gwdc_python.files import FileReference, FileReferenceList
+from gwdc_python.helpers import TimeRange, Cluster, JobStatus
+
 
 try:
     from importlib.metadata import version
 except ModuleNotFoundError:
     from importlib_metadata import version
-__version__ = version('gwcloud_python')
\ No newline at end of file
+__version__ = version('gwcloud_python')
