@@ -13,9 +13,10 @@ from gwdc_python.logger import create_logger
 
 from .bilby_job import BilbyJob
 from .event_id import EventID
+from .exceptions import custom_error_handler
 from .utils.file_download import _download_files, _save_file_map_fn, _get_file_map_fn
 from .utils.file_upload import check_file
-from .settings import GWCLOUD_ENDPOINT
+from .settings import GWCLOUD_ENDPOINT, GWCLOUD_AUTH_ENDPOINT
 
 logger = create_logger(__name__)
 
@@ -28,6 +29,8 @@ class GWCloud:
     ----------
     token : str
         API token for a Bilby user
+    auth_endpoint : str, optional
+        URL to which we send the authentication queries, by default GWCLOUD_AUTH_ENDPOINT
     endpoint : str, optional
         URL to which we send the queries, by default GWCLOUD_ENDPOINT
 
@@ -36,8 +39,13 @@ class GWCloud:
     client : GWDC
         Handles a lot of the underlying logic surrounding the queries
     """
-    def __init__(self, token, endpoint=GWCLOUD_ENDPOINT):
-        self.client = GWDC(token=token, endpoint=endpoint)
+    def __init__(self, token, auth_endpoint=GWCLOUD_AUTH_ENDPOINT, endpoint=GWCLOUD_ENDPOINT):
+        self.client = GWDC(
+            token=token,
+            auth_endpoint=auth_endpoint,
+            endpoint=endpoint,
+            custom_error_handler=custom_error_handler
+        )
         self.request = self.client.request  # Setting shorthand for simplicity
 
     def _upload_supporting_files(self, tokens, file_paths):
@@ -607,7 +615,7 @@ class GWCloud:
             # Upload the archive
             return self.upload_job_archive(description, f.name, public)
 
-    def create_event_id(self, event_id, trigger_id=None, nickname=None, is_ligo_event=False):
+    def create_event_id(self, event_id, gps_time, trigger_id=None, nickname=None, is_ligo_event=False):
         """Create an Event ID that can be assigned to Bilby Jobs
 
         **INFO**:
@@ -617,6 +625,8 @@ class GWCloud:
         ----------
         event_id : str
             ID of the event, must be of the form GW123456_123456
+        gps_time : float
+            The GPS time that this Event ID represents, e.g. 1126259462.391
         trigger_id : str, optional
             Trigger ID of the event, must be of the form S123456a, by default None
         nickname : str, optional
@@ -642,13 +652,14 @@ class GWCloud:
                 "triggerId": trigger_id,
                 "nickname": nickname,
                 "isLigoEvent": is_ligo_event,
+                "gpsTime": gps_time,
             }
         }
         data = self.request(query=query, variables=variables)
         logger.info(data['create_event_id']['result'])
         return self.get_event_id(event_id=event_id)
 
-    def update_event_id(self, event_id, trigger_id=None, nickname=None, is_ligo_event=None):
+    def update_event_id(self, event_id, gps_time=None, trigger_id=None, nickname=None, is_ligo_event=None):
         """Create an Event ID that can be assigned to Bilby Jobs
 
         **INFO**:
@@ -658,6 +669,8 @@ class GWCloud:
         ----------
         event_id : str
             ID of the event, must be of the form GW123456_123456
+        gps_time : float, optional
+            The GPS time that this Event ID represents, e.g. 1126259462.391
         trigger_id : str, optional
             Trigger ID of the event, must be of the form S123456a, by default None
         nickname : str, optional
@@ -683,6 +696,7 @@ class GWCloud:
                 "triggerId": trigger_id,
                 "nickname": nickname,
                 "isLigoEvent": is_ligo_event,
+                "gpsTime": gps_time,
             }
         }
         data = self.request(query=query, variables=variables)
@@ -735,6 +749,7 @@ class GWCloud:
                     triggerId
                     nickname
                     isLigoEvent
+                    gpsTime
                 }
             }
         """
@@ -767,6 +782,7 @@ class GWCloud:
                     triggerId
                     nickname
                     isLigoEvent
+                    gpsTime
                 }
             }
         """
